ytree\.tree\_farm\.ancestry\_short\.AncestryShort
=================================================

.. currentmodule:: ytree.tree_farm.ancestry_short

.. autoclass:: AncestryShort

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~AncestryShort.__init__
   
   

   
   
   